@@ -13,7 +13,7 @@ BEGIN {
 
 use Graph::AdjacencyMap qw(:flags :fields);
 
-our $VERSION = '0.9709';
+our $VERSION = '0.9710';
 
 require 5.006; # Weak references are absolutely required.
 
@@ -1736,9 +1736,28 @@ sub rename_vertices {
 
 sub as_hashes {
     my ($g) = @_;
-    my %e;
-    $e{ $_->[0] }{ $_->[1] } = $g->get_edge_attributes(@$_) || {} for $g->edges;
-    my %n = map +( $_ => $g->get_vertex_attributes($_) || {} ), $g->vertices;
+    my (%n, %e);
+    if ($g->is_multivertexed) {
+        for my $v ($g->vertices) {
+            $n{$v} = {
+                map +($_ => $g->get_vertex_attributes_by_id($v, $_) || {}),
+                    $g->get_multivertex_ids($v)
+            };
+        }
+    } else {
+        %n = map +($_ => $g->get_vertex_attributes($_) || {}), $g->vertices;
+    }
+    if ($g->is_multiedged) {
+        for my $e ($g->edges) {
+            $e{ $e->[0] }{ $e->[1] } = {
+                map +($_ => $g->get_edge_attributes_by_id(@$e, $_) || {}),
+                    $g->get_multiedge_ids(@$e)
+            };
+        }
+    } else {
+        $e{ $_->[0] }{ $_->[1] } = $g->get_edge_attributes(@$_) || {}
+            for $g->edges;
+    }
     ( \%n, \%e );
 }
 
@@ -3687,6 +3706,12 @@ sub path_vertices {
     $tcm->path_vertices(@_);
 }
 
+sub all_paths {
+    my $g = shift;
+    my $tcm = $g->transitive_closure_matrix;
+    $tcm->all_paths(@_);
+}
+
 sub is_reachable {
     my $g = shift;
     my $tcm = $g->transitive_closure_matrix;
